@@ -32,11 +32,11 @@ extern "C"
 
 // KDE includes.
 
-#include <kapplication.h>
-#include <kconfig.h>
-#include <kio/job.h>
-#include <klocale.h>
-#include <kmessagebox.h>
+#include <tdeapplication.h>
+#include <tdeconfig.h>
+#include <tdeio/job.h>
+#include <tdelocale.h>
+#include <tdemessagebox.h>
 #include <kstandarddirs.h>
 
 // Libkexiv2 includes.
@@ -59,7 +59,7 @@ namespace KIPIGPSSyncPlugin
 kmlExport::kmlExport(KIPI::Interface* interface)
 {
     m_interface      = interface;
-    TQWidget* parent  = KApplication::kApplication()->mainWidget();
+    TQWidget* parent  = TDEApplication::kApplication()->mainWidget();
     m_progressDialog = new KIPI::BatchProgressDialog(parent, i18n("Generating KML file..."));
 }
 
@@ -450,7 +450,7 @@ void kmlExport::generate()
     if (defectImage) 
     {
         /** @todo if defectImage==count there are no pictures exported, does it worst to continue? */
-        TQWidget* parent = KApplication::kApplication()->mainWidget();
+        TQWidget* parent = TDEApplication::kApplication()->mainWidget();
         KMessageBox::information(parent, i18n("No position data for 1 picture",
                                               "No position data for %n pictures", defectImage));
     }
@@ -465,7 +465,7 @@ void kmlExport::generate()
 
     delete kmlDocument;
 
-    KIO::moveAs(m_tempDestDir,m_baseDestDir,false);
+    TDEIO::moveAs(m_tempDestDir,m_baseDestDir,false);
     logInfo(i18n("Move to final directory"));
     m_progressDialog->close();
 }
@@ -475,7 +475,7 @@ void kmlExport::generate()
  */
 int kmlExport::getConfig()
 {
-    KConfig config("kipirc");
+    TDEConfig config("kipirc");
     config.setGroup("KMLExport Settings");
 
     m_localTarget           = config.readBoolEntry("localTarget");
@@ -497,7 +497,7 @@ int kmlExport::getConfig()
     m_GPXOpacity            = config.readNumEntry("Track Opacity", 64 );
     m_GPXAltitudeMode       = config.readNumEntry("GPX Altitude Mode", 0);
 
-    KStandardDirs dir;
+    TDEStandardDirs dir;
     m_tempDestDir   = dir.saveLocation("tmp", "kipi-kmlrexportplugin-" + TQString::number(getpid()) + '/');
     m_imageDir      = "images/";
     m_googlemapSize = 32;
